(***********************************************************************)
(*                                                                     *)
(*                           Htmlc                                     *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 2000 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* $Id: version.ml,v 1.12 2004/09/01 08:12:25 weis Exp $ *)

(* The current version of htmlc *)
let htmlc_version_number = 1.6;;
let htmlc_sub_version_number = 0;;
let htmlc_version_date = "2004-09-01";;

let htmlc_version =
  Printf.sprintf "%.2f" htmlc_version_number;;

let htmlc_full_version =
  Printf.sprintf "%.2f+%i (%s)"
    htmlc_version_number htmlc_sub_version_number htmlc_version_date;;

let print_version () =
  prerr_endline ("htmlc, version " ^ htmlc_version);;

let print_full_version () =
  prerr_endline ("htmlc, version " ^ htmlc_full_version);;

